@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 #
-# Copyright 2014-2015 OpenStack Foundation
+# Copyright 2014 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,21 +14,24 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import cotyledon
-from cotyledon import oslo_config_glue
 from oslo_config import cfg
-from oslo_log import log
 
-from ceilometer.polling import manager
+from ceilometer.agent import manager
+from ceilometer.i18n import _LW
+from ceilometer.openstack.common import log
+from ceilometer.openstack.common import service as os_service
 from ceilometer import service
 
 LOG = log.getLogger(__name__)
 
+CONF = cfg.CONF
+
 
 class MultiChoicesOpt(cfg.Opt):
     def __init__(self, name, choices=None, **kwargs):
-        super(MultiChoicesOpt, self).__init__(
-            name, type=DeduplicatedCfgList(choices), **kwargs)
+        super(MultiChoicesOpt, self).__init__(name,
+                                              type=DeduplicatedCfgList(),
+                                              **kwargs)
         self.choices = choices
 
     def _get_argparse_kwargs(self, group, **kwargs):
@@ -42,43 +45,50 @@ class MultiChoicesOpt(cfg.Opt):
 
 
 class DeduplicatedCfgList(cfg.types.List):
-    def __init__(self, choices=None, **kwargs):
-        super(DeduplicatedCfgList, self).__init__(**kwargs)
-        self.choices = choices or []
-
     def __call__(self, *args, **kwargs):
         result = super(DeduplicatedCfgList, self).__call__(*args, **kwargs)
-        result_set = set(result)
-        if len(result) != len(result_set):
-            LOG.warning("Duplicated values: %s found in CLI options, "
-                        "auto de-duplicated", result)
-            result = list(result_set)
-        if self.choices and not (result_set <= set(self.choices)):
-            raise Exception('Valid values are %s, but found %s'
-                            % (self.choices, result))
+        if len(result) != len(set(result)):
+            LOG.warning(_LW("Duplicated values: %s found in CLI options, "
+                            "auto de-duplidated"), result)
+            result = list(set(result))
         return result
 
 
 CLI_OPTS = [
     MultiChoicesOpt('polling-namespaces',
                     default=['compute', 'central'],
+                    choices=['compute', 'central', 'ipmi'],
                     dest='polling_namespaces',
                     help='Polling namespace(s) to be used while '
                          'resource polling'),
+    MultiChoicesOpt('pollster-list',
+                    default=[],
+                    dest='pollster_list',
+                    help='List of pollsters (or wildcard templates) to be '
+                         'used while polling'),
 ]
 
-
-def create_polling_service(worker_id, conf):
-    return manager.AgentManager(worker_id,
-                                conf,
-                                conf.polling_namespaces)
+CONF.register_cli_opts(CLI_OPTS)
 
 
 def main():
-    conf = cfg.ConfigOpts()
-    conf.register_cli_opts(CLI_OPTS)
-    service.prepare_service(conf=conf)
-    sm = cotyledon.ServiceManager()
-    sm.add(create_polling_service, args=(conf,))
-    oslo_config_glue.setup(sm, conf)
-    sm.run()
+    service.prepare_service()
+    os_service.launch(manager.AgentManager(CONF.polling_namespaces,
+                                           CONF.pollster_list)).wait()
+
+
+# todo(dbelova): remove it someday. Needed for backward compatibility
+def main_compute():
+    service.prepare_service()
+    os_service.launch(manager.AgentManager(['compute'])).wait()
+
+
+# todo(dbelova): remove it someday. Needed for backward compatibility
+def main_central():
+    service.prepare_service()
+    os_service.launch(manager.AgentManager(['central'])).wait()
+
+
+def main_ipmi():
+    service.prepare_service()
+    os_service.launch(manager.AgentManager(['ipmi'])).wait()
