@@ -17,86 +17,97 @@
 import collections
 
 from oslo_config import cfg
-from oslo_log import log
 from stevedore import driver
 
 import ceilometer
+from ceilometer.i18n import _
+from ceilometer.openstack.common import log
 
 
 OPTS = [
     cfg.StrOpt('hypervisor_inspector',
                default='libvirt',
-               choices=['libvirt'],
-               deprecated_for_removal=True,
-               deprecated_reason='libvirt is the only supported hypervisor',
-               help='Inspector to use for inspecting the hypervisor layer.')
+               help='Inspector to use for inspecting the hypervisor layer.'),
 ]
 
+cfg.CONF.register_opts(OPTS)
+
 
 LOG = log.getLogger(__name__)
 
-
-# Named tuple representing instance statistics
-
-class InstanceStats:
-    fields = [
-        'power_state',       # the power state of the domain
-        'cpu_number',        # number: number of CPUs
-        'cpu_time',          # time: cumulative CPU time
-        'memory_actual',     # actual: Amount of allocated memory
-        'memory_available',  # available: Amount of usable memory
-        'memory_usage',      # usage: Amount of memory used
-        'memory_resident',   #
-        'memory_swap_in',    # memory swap in
-        'memory_swap_out',   # memory swap out
-        'cpu_cycles',        # cpu_cycles: the number of cpu cycles one
-                             #   instruction needs
-        'instructions',      # instructions: the count of instructions
-        'cache_references',  # cache_references: the count of cache hits
-        'cache_misses',      # cache_misses: the count of caches misses
-    ]
-
-    def __init__(self, **kwargs):
-        for k in self.fields:
-            setattr(self, k, kwargs.pop(k, None))
-        if kwargs:
-            raise AttributeError(
-                "'InstanceStats' object has no attributes '%s'" % kwargs)
+# Named tuple representing instances.
+#
+# name: the name of the instance
+# uuid: the UUID associated with the instance
+#
+Instance = collections.namedtuple('Instance', ['name', 'UUID'])
 
 
-# Named tuple representing vNIC statistics.
+# Named tuple representing CPU statistics.
+#
+# number: number of CPUs
+# time: cumulative CPU time
+#
+CPUStats = collections.namedtuple('CPUStats', ['number', 'time'])
+
+# Named tuple representing CPU Utilization statistics.
+#
+# util: CPU utilization in percentage
+#
+CPUUtilStats = collections.namedtuple('CPUUtilStats', ['util'])
+
+# Named tuple representing Memory usage statistics.
+#
+# usage: Amount of memory used
+#
+MemoryUsageStats = collections.namedtuple('MemoryUsageStats', ['usage'])
+
+
+# Named tuple representing Resident Memory usage statistics.
+#
+# resident: Amount of resident memory
+#
+MemoryResidentStats = collections.namedtuple('MemoryResidentStats',
+                                             ['resident'])
+
+
+# Named tuple representing vNICs.
 #
 # name: the name of the vNIC
 # mac: the MAC address
 # fref: the filter ref
 # parameters: miscellaneous parameters
+#
+Interface = collections.namedtuple('Interface', ['name', 'mac',
+                                                 'fref', 'parameters'])
+
+
+# Named tuple representing vNIC statistics.
+#
 # rx_bytes: number of received bytes
 # rx_packets: number of received packets
 # tx_bytes: number of transmitted bytes
 # tx_packets: number of transmitted packets
 #
 InterfaceStats = collections.namedtuple('InterfaceStats',
-                                        ['name', 'mac', 'fref', 'parameters',
-                                         'rx_bytes', 'tx_bytes',
-                                         'rx_packets', 'tx_packets',
-                                         'rx_drop', 'tx_drop',
-                                         'rx_errors', 'tx_errors',
-                                         'rx_bytes_delta', 'tx_bytes_delta'])
+                                        ['rx_bytes', 'rx_packets',
+                                         'tx_bytes', 'tx_packets'])
 
 
 # Named tuple representing vNIC rate statistics.
 #
-# name: the name of the vNIC
-# mac: the MAC address
-# fref: the filter ref
-# parameters: miscellaneous parameters
 # rx_bytes_rate: rate of received bytes
 # tx_bytes_rate: rate of transmitted bytes
 #
 InterfaceRateStats = collections.namedtuple('InterfaceRateStats',
-                                            ['name', 'mac',
-                                             'fref', 'parameters',
-                                             'rx_bytes_rate', 'tx_bytes_rate'])
+                                            ['rx_bytes_rate', 'tx_bytes_rate'])
+
+
+# Named tuple representing disks.
+#
+# device: the device name for the disk
+#
+Disk = collections.namedtuple('Disk', ['device'])
 
 
 # Named tuple representing disk statistics.
@@ -108,11 +119,9 @@ InterfaceRateStats = collections.namedtuple('InterfaceRateStats',
 # errors: number of errors
 #
 DiskStats = collections.namedtuple('DiskStats',
-                                   ['device',
-                                    'read_bytes', 'read_requests',
+                                   ['read_bytes', 'read_requests',
                                     'write_bytes', 'write_requests',
-                                    'errors', 'wr_total_times',
-                                    'rd_total_times'])
+                                    'errors'])
 
 # Named tuple representing disk rate statistics.
 #
@@ -122,12 +131,26 @@ DiskStats = collections.namedtuple('DiskStats',
 # write_requests_rate: number of write operations per second
 #
 DiskRateStats = collections.namedtuple('DiskRateStats',
-                                       ['device',
-                                        'read_bytes_rate',
+                                       ['read_bytes_rate',
                                         'read_requests_rate',
                                         'write_bytes_rate',
                                         'write_requests_rate'])
 
+# Named tuple representing disk latency statistics.
+#
+# disk_latency: average disk latency
+#
+DiskLatencyStats = collections.namedtuple('DiskLatencyStats',
+                                          ['disk_latency'])
+
+# Named tuple representing disk iops statistics.
+#
+# iops: number of iops per second
+#
+DiskIOPSStats = collections.namedtuple('DiskIOPSStats',
+                                       ['iops_count'])
+
+
 # Named tuple representing disk Information.
 #
 # capacity: capacity of the disk
@@ -135,8 +158,7 @@ DiskRateStats = collections.namedtuple('DiskRateStats',
 # physical: usage of the disk
 
 DiskInfo = collections.namedtuple('DiskInfo',
-                                  ['device',
-                                   'capacity',
+                                  ['capacity',
                                    'allocation',
                                    'physical'])
 
@@ -145,7 +167,7 @@ DiskInfo = collections.namedtuple('DiskInfo',
 #
 class InspectorException(Exception):
     def __init__(self, message=None):
-        super().__init__(message)
+        super(InspectorException, self).__init__(message)
 
 
 class InstanceNotFoundException(InspectorException):
@@ -162,33 +184,36 @@ class NoDataException(InspectorException):
 
 # Main virt inspector abstraction layering over the hypervisor API.
 #
-class Inspector:
+class Inspector(object):
 
-    def __init__(self, conf):
-        self.conf = conf
-
-    def inspect_instance(self, instance, duration):
+    def inspect_cpus(self, instance):
         """Inspect the CPU statistics for an instance.
 
         :param instance: the target instance
-        :param duration: the last 'n' seconds, over which the value should be
-               inspected
-        :return: the instance stats
+        :return: the number of CPUs and cumulative CPU time
         """
         raise ceilometer.NotImplementedError
 
-    def inspect_vnics(self, instance, duration):
-        """Inspect the vNIC statistics for an instance.
+    def inspect_cpu_util(self, instance, duration=None):
+        """Inspect the CPU Utilization (%) for an instance.
 
         :param instance: the target instance
         :param duration: the last 'n' seconds, over which the value should be
                inspected
+        :return: the percentage of CPU utilization
+        """
+        raise ceilometer.NotImplementedError
+
+    def inspect_vnics(self, instance):
+        """Inspect the vNIC statistics for an instance.
+
+        :param instance: the target instance
         :return: for each vNIC, the number of bytes & packets
                  received and transmitted
         """
         raise ceilometer.NotImplementedError
 
-    def inspect_vnic_rates(self, instance, duration):
+    def inspect_vnic_rates(self, instance, duration=None):
         """Inspect the vNIC rate statistics for an instance.
 
         :param instance: the target instance
@@ -199,18 +224,26 @@ class Inspector:
         """
         raise ceilometer.NotImplementedError
 
-    def inspect_disks(self, instance, duration):
+    def inspect_disks(self, instance):
         """Inspect the disk statistics for an instance.
 
         :param instance: the target instance
-        :param duration: the last 'n' seconds, over which the value should be
-               inspected
         :return: for each disk, the number of bytes & operations
                  read and written, and the error count
         """
         raise ceilometer.NotImplementedError
 
-    def inspect_disk_rates(self, instance, duration):
+    def inspect_memory_usage(self, instance, duration=None):
+        """Inspect the memory usage statistics for an instance.
+
+        :param instance: the target instance
+        :param duration: the last 'n' seconds, over which the value should be
+               inspected
+        :return: the amount of memory used
+        """
+        raise ceilometer.NotImplementedError
+
+    def inspect_disk_rates(self, instance, duration=None):
         """Inspect the disk statistics as rates for an instance.
 
         :param instance: the target instance
@@ -221,25 +254,38 @@ class Inspector:
         """
         raise ceilometer.NotImplementedError
 
-    def inspect_disk_info(self, instance, duration):
+    def inspect_disk_latency(self, instance):
+        """Inspect the disk statistics as rates for an instance.
+
+        :param instance: the target instance
+        :return: for each disk, the average disk latency
+        """
+        raise ceilometer.NotImplementedError
+
+    def inspect_disk_iops(self, instance):
+        """Inspect the disk statistics as rates for an instance.
+
+        :param instance: the target instance
+        :return: for each disk, the number of iops per second
+        """
+        raise ceilometer.NotImplementedError
+
+    def inspect_disk_info(self, instance):
         """Inspect the disk information for an instance.
 
         :param instance: the target instance
-        :param duration: the last 'n' seconds, over which the value should be
-               inspected
-        :return: for each disk , capacity , allocation and usage
+        :return: for each disk , capacity , alloaction and usage
         """
         raise ceilometer.NotImplementedError
 
 
-def get_hypervisor_inspector(conf):
+def get_hypervisor_inspector():
     try:
         namespace = 'ceilometer.compute.virt'
         mgr = driver.DriverManager(namespace,
-                                   conf.hypervisor_inspector,
-                                   invoke_on_load=True,
-                                   invoke_args=(conf, ))
+                                   cfg.CONF.hypervisor_inspector,
+                                   invoke_on_load=True)
         return mgr.driver
     except ImportError as e:
-        LOG.error("Unable to load the hypervisor inspector: %s", e)
-        return Inspector(conf)
+        LOG.error(_("Unable to load the hypervisor inspector: %s") % e)
+        return Inspector()
