@@ -15,18 +15,28 @@
 """Storage backend management
 """
 
+from oslo.db import options as db_options
 from oslo_config import cfg
-from oslo_db import options as db_options
-from oslo_log import log
 import retrying
+import six
 import six.moves.urllib.parse as urlparse
 from stevedore import driver
 
+from ceilometer.openstack.common import log
 from ceilometer import utils
 
 
 LOG = log.getLogger(__name__)
 
+OLD_OPTS = [
+    cfg.StrOpt('database_connection',
+               secret=True,
+               help='DEPRECATED - Database connection string.',
+               ),
+]
+
+cfg.CONF.register_opts(OLD_OPTS)
+
 
 OPTS = [
     cfg.IntOpt('metering_time_to_live',
@@ -40,30 +50,45 @@ OPTS = [
                help=("Number of seconds that events are kept "
                      "in the database for (<= 0 means forever).")),
     cfg.StrOpt('metering_connection',
-               secret=True,
+               default=None,
                help='The connection string used to connect to the metering '
                'database. (if unset, connection is used)'),
+    cfg.StrOpt('alarm_connection',
+               default=None,
+               help='The connection string used to connect to the alarm '
+               'database. (if unset, connection is used)'),
     cfg.StrOpt('event_connection',
-               secret=True,
+               default=None,
                help='The connection string used to connect to the event '
                'database. (if unset, connection is used)'),
-    cfg.BoolOpt('sql-expire-samples-only',
-                default=False,
-                help="Indicates if expirer expires only samples. If set true,"
-                " expired samples will be deleted, but residual"
-                " resource and meter definition data will remain."),
+    cfg.StrOpt('mongodb_replica_set',
+               default='',
+               help='The name of the replica set which is used to connect to '
+                    'MongoDB database. If it is set, MongoReplicaSetClient '
+                    'will be used instead of MongoClient.'),
+    cfg.IntOpt('db2nosql_resource_id_maxlen',
+               default=512,
+               help="The max length of resources id in DB2 nosql, "
+                    "the value should be larger than len(hostname) * 2 "
+                    "as compute node's resource id is <hostname>_<nodename>."),
 ]
 
 cfg.CONF.register_opts(OPTS, group='database')
 
+CLI_OPTS = [
+    cfg.BoolOpt('sql-expire-samples-only',
+                default=False,
+                help="Indicates if expirer expires only samples. If set true,"
+                     " expired samples will be deleted, but residual"
+                     " resource and meter definition data will remain.",
+                ),
+]
+
+cfg.CONF.register_cli_opts(CLI_OPTS)
 
 db_options.set_defaults(cfg.CONF)
 
 
-class StorageUnknownWriteError(Exception):
-    """Error raised when an unknown error occurs while recording."""
-
-
 class StorageBadVersion(Exception):
     """Error raised when the storage backend version is not good enough."""
 
@@ -80,6 +105,9 @@ def get_connection_from_config(conf, purpose='metering'):
     @retrying.retry(wait_fixed=conf.database.retry_interval * 1000,
                     stop_max_attempt_number=retries if retries >= 0 else None)
     def _inner():
+        if conf.database_connection:
+            conf.set_override('connection', conf.database_connection,
+                              group='database')
         namespace = 'ceilometer.%s.storage' % purpose
         url = (getattr(conf.database, '%s_connection' % purpose) or
                conf.database.connection)
@@ -157,3 +185,42 @@ class SampleFilter(object):
                  self.source,
                  self.metaquery,
                  self.message_id))
+
+
+class EventFilter(object):
+    """Properties for building an Event query.
+
+    :param start_timestamp: UTC start datetime (mandatory)
+    :param end_timestamp: UTC end datetime (mandatory)
+    :param event_type: the name of the event. None for all.
+    :param message_id: the message_id of the event. None for all.
+    :param traits_filter: the trait filter dicts, all of which are optional.
+      This parameter is a list of dictionaries that specify trait values:
+
+    .. code-block:: python
+
+        {'key': <key>,
+        'string': <value>,
+        'integer': <value>,
+        'datetime': <value>,
+        'float': <value>,
+        'op': <eq, lt, le, ne, gt or ge> }
+    """
+
+    def __init__(self, start_timestamp=None, end_timestamp=None,
+                 event_type=None, message_id=None, traits_filter=None):
+        self.start_timestamp = utils.sanitize_timestamp(start_timestamp)
+        self.end_timestamp = utils.sanitize_timestamp(end_timestamp)
+        self.message_id = message_id
+        self.event_type = event_type
+        self.traits_filter = traits_filter or []
+
+    def __repr__(self):
+        return ("<EventFilter(start_timestamp: %s,"
+                " end_timestamp: %s,"
+                " event_type: %s,"
+                " traits: %s)>" %
+                (self.start_timestamp,
+                 self.end_timestamp,
+                 self.event_type,
+                 six.text_type(self.traits_filter)))
