@@ -18,10 +18,10 @@ import json
 
 import bson.json_util
 from happybase.hbase import ttypes
-from oslo_log import log
 import six
 
 from ceilometer.i18n import _
+from ceilometer.openstack.common import log
 from ceilometer import utils
 
 LOG = log.getLogger(__name__)
@@ -297,7 +297,7 @@ def make_meter_query_for_resource(start_timestamp, start_timestamp_op,
     if mq:
         meter_q = " AND ".join(mq)
         # If there is a filtering on time_range we need to point that
-        # qualifiers should start with m_. Otherwise in case e.g.
+        # qualifiers should start with m_. Overwise in case e.g.
         # QualifierFilter (>=, 'binaryprefix:m_9222030811134775808')
         # qualifier 's_test' satisfies the filter and will be returned.
         meter_q = _QualifierFilter("=", '') + " AND " + meter_q
@@ -315,7 +315,7 @@ def make_general_rowkey_scan(rts_start=None, rts_end=None, some_id=None):
     if not rts_start:
         # NOTE(idegtiarov): Here we could not use chr > 122 because chr >= 123
         # will be quoted and character will be turn in a composition that is
-        # started with '%' (chr(37)) that lexicographically is less than chr
+        # started with '%' (chr(37)) that lexicographically is less then chr
         # of number
         rts_start = chr(122)
     end_row = prepare_key(some_id, rts_start)
@@ -385,7 +385,7 @@ def deserialize_entry(entry, get_raw_meta=True):
     else:
         metadata = metadata_flattened
 
-    return flatten_result, meters, metadata
+    return flatten_result, sources, meters, metadata
 
 
 def serialize_entry(data=None, **kwargs):
@@ -471,9 +471,9 @@ def create_tables(conn, tables, column_families):
                               separator=conn.table_prefix_separator,
                               table_name=table))
 
-            LOG.warning(_("Cannot create table %(table_name)s   "
-                        "it already exists. Ignoring error")
-                        % {'table_name': table})
+            LOG.warn(_("Cannot create table %(table_name)s   "
+                       "it already exists. Ignoring error")
+                     % {'table_name': table})
 
 
 def quote(s, *args):
